nbxmpp.tls_nb.SSLWrapper.Error

Package nbxmpp :: Module tls_nb :: Class SSLWrapper :: Class Error |
[hide private]
[frames] | no frames]

# Class Error

source code

Generic SSL Error Wrapper

Instance Methods | [hide private]
__init__(self, sock=None, exc=None, errno=None, strerror=None, peer=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__str__(self) str(x) | source code
Inherited from `exceptions.IOError`: `__new__` Inherited from `exceptions.EnvironmentError`: `__reduce__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.EnvironmentError`: `errno`, `filename`, `strerror` Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, sock=None, exc=None, errno=None, strerror=None, peer=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)